encode_connect_network

Function encode_connect_network 

pub fn encode_connect_network(network_id: &[u8], breadcrumb: u64) -> Vec<u8> 
Encode ConnectNetwork (spec 11.9.6.6).

network_id is the SSID bytes for Wi-Fi networks (re-uses the ssid field as the network identity per spec 11.9.5.2). For Wi-Fi commissioning the value is identical to the SSID supplied to encode_add_or_update_wifi_network.